--------------------------------------------------------------------------------
-- Title   : RESET
-- Project : TimEX3
--------------------------------------------------------------------------------
-- Description : Reset
--------------------------------------------------------------------------------
-- File     : reset.vhd
-- Revision : x.x.x
-- Created  : October 26, 2012
-- Updated  : November 05, 2012
--------------------------------------------------------------------------------
-- Author       : Jean-Paul Ricaud
-- Organization : Synchrotron Soleil
-- Web          : http://www.synchrotron-soleil.fr
-- Email        : jean-paul.ricaud@synchrotron-soleil.fr
--------------------------------------------------------------------------------
-- Copyright (C) 2012 - Synchrotron Soleil
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Lesser General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU Lesser General Public License for more details.
--
-- You should have received a copy of the GNU Lesser General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>
--------------------------------------------------------------------------------
--
--------------------------------------------------------------------------------
-- Modifications :
--
--------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

--------------------------------------------------------------------------------
--------------------------------- ENTITY ---------------------------------------
--------------------------------------------------------------------------------
entity reset is
  port (
    -- Internal bus
    p_ext_RESETn : in std_logic;  -- external reset comming from the board reset chip
    p_clk60MHz   : in std_logic;  -- clock 60 MHz
    p_cmd_REG0   : in std_logic;  -- command register bit 0 ; p_CSW = "000000000000001"
    p_CSW        : in std_logic;  -- chip select of internal write transfert
    -- Other signals
    p_fpga_RST   : out std_logic; -- internal reset of the FPGA (process)
    p_board_RST  : out std_logic  -- mother board global reset
  );
end reset;

--------------------------------------------------------------------------------
------------------------------- ARCHITECTURE -----------------------------------
--------------------------------------------------------------------------------
architecture rtl_reset of reset is
  ------------------------------------------------------------------------------
  -- constant
  ------------------------------------------------------------------------------

  ------------------------------------------------------------------------------
  -- signal
  ------------------------------------------------------------------------------
  signal s_synchroRST : std_logic; -- synchronous reset
  signal s_holdRST1   : std_logic; -- extrenal asynchronous reset hold
  signal s_holdRST2   : std_logic; -- extrenal asynchronous reset hold

  ------------------------------------------------------------------------------
  -- Components
  ------------------------------------------------------------------------------

  ------------------------------------------------------------------------------
  --------------------------------- Main ---------------------------------------
  ------------------------------------------------------------------------------
  begin

  -- Synchronization of the external async reset with the 60MHz clock
  process (p_clk60MHz, p_ext_RESETn)
  begin
    if (p_ext_RESETn = '0') then
      s_synchroRST <= '1';
      s_holdRST1   <= '0';
      s_holdRST2   <= '0';
    elsif (rising_edge(p_clk60MHz)) then
      s_holdRST1 <= '1';
      s_holdRST2 <= s_holdRST1;
      if (s_holdRST2 = '0' or s_holdRST1 = '0') then
        s_synchroRST <= '1'; -- reset
      else
        s_synchroRST <= '0';
      end if;
    end if;
  end process;

  -- FPGA process reset
  process (p_clk60MHz, s_synchroRST)
  begin
    if (rising_edge(p_clk60MHz)) then
      if (s_synchroRST = '1') then
        p_fpga_RST <= '1';
      elsif ((p_CSW = '1') and (p_cmd_REG0 = '1')) then
        p_fpga_RST <= '1'; -- reset the FPGA's processes
      else
        p_fpga_RST <= '0';
      end if;
    end if;
  end process;

  ------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  p_board_RST <= '0'; -- !!! SET TO 0 AT POWER ON !!!

end rtl_reset;
