--------------------------------------------------------------------------------
-- Title   : Register Mutiplexer
-- Project : TimEX3
--------------------------------------------------------------------------------
-- Description : Register multiplexer
--  SW 5-4-3-2-1-0
--     1-1-1-1-1-1 : board test
--     0-0-0-0-1-1 : LINAC monitoring
--     0-0-0-0-1-0 : LINAC multipulse
--     0-0-0-0-0-1 : top-up trigger
--     0-0-0-0-0-0 : duplication
--------------------------------------------------------------------------------
-- File     : cPCI_registerMux.vhdl
-- Revision : x.x.x
-- Created  : November 17, 2013
-- Updated  : December 05, 2013
--------------------------------------------------------------------------------
-- Author       : Jean-Paul Ricaud
-- Organization : Synchrotron Soleil
-- Web          : http://www.synchrotron-soleil.fr
-- Email        : jean-paul.ricaud@synchrotron-soleil.fr
--------------------------------------------------------------------------------
-- Copyright (C) 2012 - 2013 Synchrotron Soleil
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Lesser General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU Lesser General Public License for more details.
--
-- You should have received a copy of the GNU Lesser General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>
--------------------------------------------------------------------------------
--
--------------------------------------------------------------------------------
-- Modifications :
--
--------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

library work;
use work.registers_init.all;
use work.type_lib.all;

--------------------------------------------------------------------------------
--------------------------------- ENTITY ---------------------------------------
--------------------------------------------------------------------------------
entity cPCI_registerMux is
  port (
    -- cPCI registers
    p_wRegister      : in register_array;
    p_wRegister_init : out register_array;

    p_rRegister      : out register_array;

    -- Mux in / out
    p_mux_wRegister   : out register_array;
    p_mux_rRegister   : in  register_array;

    p_mux_csw         : in  std_logic_vector (15 downto 0); -- chip select of internal write transfert
    p_mux_csr         : in  std_logic_vector (15 downto 0); -- chip select of internal read transfert
    p_csw             : out std_logic_vector (15 downto 0);
    p_csr             : out std_logic_vector (15 downto 0);

    -- Congig pin
    p_mux_SWsel       : in  std_logic_vector (5 downto 0)
  );
end entity cPCI_registerMux;

--------------------------------------------------------------------------------
------------------------------- ARCHITECTURE -----------------------------------
--------------------------------------------------------------------------------
architecture rtl_cPCI_registerMux of cPCI_registerMux is
  ------------------------------------------------------------------------------
  -- constant
  ------------------------------------------------------------------------------

  ------------------------------------------------------------------------------
  -- signal
  ------------------------------------------------------------------------------

  ------------------------------------------------------------------------------
  -- Components
  ------------------------------------------------------------------------------

  ------------------------------------------------------------------------------
  --------------------------------- Main ---------------------------------------
  ------------------------------------------------------------------------------
  begin

  -- Duplication write
  with p_mux_SWsel select
    p_mux_wRegister(0) <=
      p_wRegister(0) when "000000",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_mux_wRegister(1) <=
      p_wRegister(1) when "000000",
      X"00000000"  when OTHERS;

  -- Top-up write
  with p_mux_SWsel select
    p_mux_wRegister(2) <=
      p_wRegister(0) when "000001",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_mux_wRegister(3) <=
      p_wRegister(1) when "000001",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_mux_wRegister(4) <=
      p_wRegister(2) when "000001",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_mux_wRegister(5) <=
      p_wRegister(3) when "000001",
      X"00000000"  when OTHERS;

  -- LINAC SPM multi-pulses write
  with p_mux_SWsel select
    p_mux_wRegister(6) <=
      p_wRegister(0) when "000010",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_mux_wRegister(7) <=
      p_wRegister(1) when "000010",
      X"00000000"  when OTHERS;

  -- LINAC monitoring write
  with p_mux_SWsel select
    p_mux_wRegister(8) <=
      p_wRegister(0) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_mux_wRegister(9) <=
      p_wRegister(1) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_mux_wRegister(10) <=
      p_wRegister(2) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_mux_wRegister(11) <=
      p_wRegister(3) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_mux_wRegister(12) <=
      p_wRegister(4) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_mux_wRegister(13) <=
      p_wRegister(5) when "000011",
      X"00000000"  when OTHERS;

  ------------------------------------------------------------------------------
  ------------------------------------------------------------------------------

  -- Write registers init values mux
  with p_mux_SWsel select
    p_wRegister_init(0) <=
      c_wRegister_init(0) when "000000",
      c_wRegister_init(2) when "000001",
      c_wRegister_init(6) when "000010",
      c_wRegister_init(8) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_wRegister_init(1) <=
      c_wRegister_init(1) when "000000",
      c_wRegister_init(3) when "000001",
      c_wRegister_init(7) when "000010",
      c_wRegister_init(9) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_wRegister_init(2) <=
      c_wRegister_init(4)  when "000001",
      c_wRegister_init(10) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_wRegister_init(3) <=
      c_wRegister_init(5)  when "000001",
      c_wRegister_init(11) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_wRegister_init(4) <=
      c_wRegister_init(12) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_wRegister_init(5) <=
      c_wRegister_init(13) when "000011",
      X"00000000"  when OTHERS;

  p_wRegister_init(6)  <= X"00000000";
  p_wRegister_init(7)  <= X"00000000";
  p_wRegister_init(8)  <= X"00000000";
  p_wRegister_init(9)  <= X"00000000";
  p_wRegister_init(10) <= X"00000000";
  p_wRegister_init(11) <= X"00000000";
  p_wRegister_init(12) <= X"00000000";
  p_wRegister_init(13) <= X"00000000";

  ------------------------------------------------------------------------------
  ------------------------------------------------------------------------------

  -- Read mux
  with p_mux_SWsel select
    p_rRegister(0) <=
      p_mux_rRegister(0) when "000000",
      p_mux_rRegister(2) when "000001",
      p_mux_rRegister(6) when "000010",
      p_mux_rRegister(8) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_rRegister(1) <=
      p_mux_rRegister(1) when "000000",
      p_mux_rRegister(3) when "000001",
      p_mux_rRegister(7) when "000010",
      p_mux_rRegister(9) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_rRegister(2) <=
      p_mux_rRegister(4)  when "000001",
      p_mux_rRegister(10) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_rRegister(3) <=
      p_mux_rRegister(5)  when "000001",
      p_mux_rRegister(11) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_rRegister(4) <=
      p_mux_rRegister(12) when "000011",
      X"00000000"  when OTHERS;

  with p_mux_SWsel select
    p_rRegister(5) <=
      p_mux_rRegister(13) when "000011",
      X"00000000"  when OTHERS;

  p_rRegister(6)  <= X"00000000";
  p_rRegister(7)  <= X"00000000";
  p_rRegister(8)  <= X"00000000";
  p_rRegister(9)  <= X"00000000";
  p_rRegister(10) <= X"00000000";
  p_rRegister(11) <= X"00000000";
  p_rRegister(12) <= X"00000000";
  p_rRegister(13) <= X"00000000";

  ------------------------------------------------------------------------------
  ------------------------------------------------------------------------------

  p_csw(0)  <= p_mux_csw(0);  -- cmd register

  -- Duplication write strobe mux
  with p_mux_SWsel select
    p_csw(1) <=
      p_mux_csw(1) when "000000",
      '0'  when OTHERS;

  with p_mux_SWsel select
    p_csw(2) <=
      p_mux_csw(2) when "000000",
      '0'  when OTHERS;

  -- Top-up write strobe mux
  with p_mux_SWsel select
    p_csw(3) <=
      p_mux_csw(1) when "000001",
      '0'  when OTHERS;

  with p_mux_SWsel select
    p_csw(4) <=
      p_mux_csw(2) when "000001",
      '0'  when OTHERS;

  with p_mux_SWsel select
    p_csw(5) <=
      p_mux_csw(3) when "000001",
      '0'  when OTHERS;

  with p_mux_SWsel select
    p_csw(6) <=
      p_mux_csw(4) when "000001",
      '0'  when OTHERS;

  -- LINAC multipulse write strobe mux
  with p_mux_SWsel select
    p_csw(7) <=
      p_mux_csw(1) when "000010",
      '0'  when OTHERS;

  with p_mux_SWsel select
    p_csw(8) <=
      p_mux_csw(2) when "000010",
      '0'  when OTHERS;

  -- LINAC monitoring write strobe mux
  with p_mux_SWsel select
    p_csw(9) <=
      p_mux_csw(1) when "000011",
      '0'  when OTHERS;

  with p_mux_SWsel select
    p_csw(10) <=
      p_mux_csw(2) when "000011",
      '0'  when OTHERS;

  with p_mux_SWsel select
    p_csw(11) <=
      p_mux_csw(3) when "000011",
      '0'  when OTHERS;

  with p_mux_SWsel select
    p_csw(12) <=
      p_mux_csw(4) when "000011",
      '0'  when OTHERS;

  with p_mux_SWsel select
    p_csw(13) <=
      p_mux_csw(5) when "000011",
      '0'  when OTHERS;

  with p_mux_SWsel select
    p_csw(14) <=
      p_mux_csw(6) when "000011",
      '0'  when OTHERS;

  p_csw(15) <= p_mux_csw(15);

  ------------------------------------------------------------------------------
  ------------------------------------------------------------------------------

  p_csr(1)  <= p_mux_csr(1);
  p_csr(2)  <= p_mux_csr(2);
  p_csr(3)  <= p_mux_csr(3);
  p_csr(4)  <= p_mux_csr(4);
  p_csr(5)  <= p_mux_csr(5);
  p_csr(6)  <= p_mux_csr(6);
  p_csr(7)  <= p_mux_csr(7);
  p_csr(8)  <= p_mux_csr(8);
  p_csr(9)  <= p_mux_csr(9);
  p_csr(10) <= p_mux_csr(10);
  p_csr(11) <= p_mux_csr(11);
  p_csr(12) <= p_mux_csr(12);
  p_csr(13) <= p_mux_csr(13);
  p_csr(14) <= p_mux_csr(14);
  p_csr(15) <= p_mux_csr(15);

  ------------------------------------------------------------------------------
  ------------------------------------------------------------------------------

end architecture rtl_cPCI_registerMux;

