-------------------------------------------------------------------------------
-- Title   : Top-up gating and beam lost management
-- Project : TimEX3
-------------------------------------------------------------------------------
-- Description : Set p_injError during an injection gating or a beam lost
--               gating
-------------------------------------------------------------------------------
-- File     : topup_injError.vhdl
-- Revision : x.x.x
-- Created  : April 12, 2012
-- Updated  : April 12, 2013
-------------------------------------------------------------------------------
-- Author       : Jean-Paul Ricaud
-- Organization : Synchrotron Soleil
-- Web          : http://www.synchrotron-soleil.fr
-- Email        : jean-paul.ricaud@synchrotron-soleil.fr
-------------------------------------------------------------------------------
-- Copyright (C) 2012 - 2013 Synchrotron Soleil
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Lesser General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU Lesser General Public License for more details.
--
-- You should have received a copy of the GNU Lesser General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>
-------------------------------------------------------------------------------
--
-------------------------------------------------------------------------------
-- Modifications :
--
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

-------------------------------------------------------------------------------
--------------------------------- ENTITY --------------------------------------
-------------------------------------------------------------------------------
entity topup_injError is
  port (
    p_clk1kHz    : in  std_logic;
    p_gateWindow : in  std_logic;
    p_beamLost   : in  std_logic;
    p_injError   : out std_logic
  );
end entity topup_injError;

-------------------------------------------------------------------------------
------------------------------- ARCHITECTURE ----------------------------------
-------------------------------------------------------------------------------
architecture rtl_topup_injError of topup_injError is
  -----------------------------------------------------------------------------
  -- constant
  -----------------------------------------------------------------------------

  -----------------------------------------------------------------------------
  -- signal
  -----------------------------------------------------------------------------

  -----------------------------------------------------------------------------
  -- Components
  -----------------------------------------------------------------------------

  -----------------------------------------------------------------------------
  --------------------------------- Main --------------------------------------
  -----------------------------------------------------------------------------
  begin

  process (p_clk1kHz)
  begin
    if (rising_edge(p_clk1kHz)) then
      p_injError <= p_beamLost or p_gateWindow;
    end if;
  end process;

  -----------------------------------------------------------------------------
  -----------------------------------------------------------------------------

end architecture rtl_topup_injError;

