-------------------------------------------------------------------------------
-- Title   : Top-up LEDs
-- Project : TimEX3
-------------------------------------------------------------------------------
-- Description : LEDs manager
--               Green LED on        = board OK
--               Green LED blincking = board OK and gating signal active
--               Red LED on          = beam lost signal active
--               Red LED off         = beam lost signal off
-------------------------------------------------------------------------------
-- File     : topup_gating.vhdl
-- Revision : x.x.x
-- Created  : October 26, 2012
-- Updated  : April 26, 2013
-------------------------------------------------------------------------------
-- Author       : Jean-Paul Ricaud
-- Organization : Synchrotron Soleil
-- Web          : http://www.synchrotron-soleil.fr
-- Email        : jean-paul.ricaud@synchrotron-soleil.fr
-------------------------------------------------------------------------------
-- Copyright (C) 2012 - 2013 Synchrotron Soleil
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Lesser General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU Lesser General Public License for more details.
--
-- You should have received a copy of the GNU Lesser General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>
-------------------------------------------------------------------------------
--
-------------------------------------------------------------------------------
-- Modifications :
--
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

-------------------------------------------------------------------------------
--------------------------------- ENTITY --------------------------------------
-------------------------------------------------------------------------------
entity topup_leds is
  port (
    p_clk500mHz : in  std_logic;
    p_State     : in  std_logic;
    p_Error     : in  std_logic;
    p_ledOut    : out std_logic_vector (1 downto 0)
  );
end entity topup_leds;

-------------------------------------------------------------------------------
------------------------------- ARCHITECTURE ----------------------------------
-------------------------------------------------------------------------------
architecture rtl_topup_leds of topup_leds is
  -----------------------------------------------------------------------------
  -- constant
  -----------------------------------------------------------------------------

  -----------------------------------------------------------------------------
  -- signal
  -----------------------------------------------------------------------------
  signal s_ledInj : std_logic;

  -----------------------------------------------------------------------------
  -- Components
  -----------------------------------------------------------------------------

  -----------------------------------------------------------------------------
  --------------------------------- Main --------------------------------------
  -----------------------------------------------------------------------------
  begin

  process (p_clk500mHz)
  begin
    if (rising_edge(p_clk500mHz)) then
      if (p_State = '1') then
        s_ledInj <= not s_ledInj;  -- Injection occuring
      else
        s_ledInj <= '1';
      end if;
    end if;
  end process;

  -----------------------------------------------------------------------------
  -----------------------------------------------------------------------------
  p_ledOut(0) <= p_Error;  -- Red LED
  p_ledOut(1) <= s_ledInj; -- Green LED

end architecture rtl_topup_leds;

