--------------------------------------------------------------------------------
-- Title   : clock sources testbench
-- Project : TimEX3
--------------------------------------------------------------------------------
-- Description : sub frequecy clocks generated from the main clock ; test bench
--------------------------------------------------------------------------------
-- File     : clk_sources_tb.vhd
-- Revision : x.x.x
-- Created  : October 30, 2012
-- Updated  : November 09, 2012
--------------------------------------------------------------------------------
-- Author       : Jean-Paul Ricaud
-- Organization : Synchrotron Soleil
-- Web          : http://www.synchrotron-soleil.fr
-- Email        : jean-paul.ricaud@synchrotron-soleil.fr
--------------------------------------------------------------------------------
-- Copyright (C) 2012 - Synchrotron Soleil
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Lesser General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU Lesser General Public License for more details.
--
-- You should have received a copy of the GNU Lesser General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>
--------------------------------------------------------------------------------
--
--------------------------------------------------------------------------------
-- Modifications :
--
--------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

--------------------------------------------------------------------------------
--------------------------------- ENTITY ---------------------------------------
--------------------------------------------------------------------------------
entity clk_sources_tb is
end entity clk_sources_tb;

--------------------------------------------------------------------------------
------------------------------- ARCHITECTURE -----------------------------------
--------------------------------------------------------------------------------
architecture archi_clk_sources_tb of clk_sources_tb is

  -- constants
  constant Period_60MHz  : TIME := 10000.000 ps;

  -- signals
  signal s_clk_60    : std_logic;
  signal s_rst_sr    : std_logic;
  signal s_clk1kHz   : std_logic;
  signal s_clk500mHz : std_logic;

  ----------------------------------------------------------------------------
  ----------------------------------------------------------------------------
  begin

  -- Frequency divider
  DUT : entity work.clk_sources (rtl_clk_sources)
  port map (
    p_clk60MHz  => s_clk_60,
    p_reset     => s_rst_sr,
    p_clk1kHz   => s_clk1kHz,
    p_clk500mHz => s_clk500mHz
  );

  -- Clock generator
  process
  begin
    s_clk_60 <= '0';
    wait for (Period_60MHz / 2);
    s_clk_60 <= '1';
    wait for (Period_60MHz / 2);
  end process;

  process
  begin
    -- Init states
    s_rst_sr <= '0';
    wait for 10 ns;
    s_rst_sr <= '1';
    wait for 10 ns;
    s_rst_sr <= '0';

    -- *** END ***
    wait;
  end process;

  -----------------------------------------------------------------------------
  -----------------------------------------------------------------------------

end architecture archi_clk_sources_tb;
